@@ -146,6 +146,7 @@ var group__spa__utils =
     [ "SPA_MSEC_PER_SEC", "group__spa__utils.html#gacc9914448bc9fd68ae5ccf004c401bcb", null ],
     [ "SPA_N_ELEMENTS", "group__spa__utils.html#ga796e3d4570d8d539ea5886074a646a11", null ],
     [ "spa_nop", "group__spa__utils.html#gae8d35b670e70b6cdba489ca76b5791d4", null ],
+    [ "SPA_NORETURN", "group__spa__utils.html#ga01ba22304e834c86556e645614f65d84", null ],
     [ "SPA_NSEC_PER_MSEC", "group__spa__utils.html#ga6259b69a24b203050fe69cacac57748a", null ],
     [ "SPA_NSEC_PER_SEC", "group__spa__utils.html#ga7b3174639eb92d4c045a2bbc72a035df", null ],
     [ "SPA_NSEC_PER_USEC", "group__spa__utils.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0", null ],
@@ -216,7 +217,9 @@ var group__spa__utils =
     [ "spa_ringbuffer_write_data", "group__spa__utils.html#ga2326c5aa37b3bd9e3473beb06395e786", null ],
     [ "spa_ringbuffer_write_update", "group__spa__utils.html#gadf0f7d4be854e463753cd082f82c18b9", null ],
     [ "spa_scnprintf", "group__spa__utils.html#ga0c8bfe9776d2357cc87f56fcfeb56ce6", null ],
+    [ "spa_strendswith", "group__spa__utils.html#ga89163c63fdbf362008c4215aa4c30b32", null ],
     [ "spa_streq", "group__spa__utils.html#ga3bacdbb55417881c16b6c9be7113cd35", null ],
     [ "spa_strneq", "group__spa__utils.html#ga1b7fac98c4422b0945f1829243567414", null ],
+    [ "spa_strstartswith", "group__spa__utils.html#ga67168486cf1067d2f0a33c1437545d0e", null ],
     [ "spa_vscnprintf", "group__spa__utils.html#ga4d59eb3327dc1b56652b0549eb440163", null ]
 ];
\ No newline at end of file
